aboutsummaryrefslogtreecommitdiffstats
path: root/src/ports/SkFontMgr_empty_factory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/ports/SkFontMgr_empty_factory.cpp')
-rw-r--r--src/ports/SkFontMgr_empty_factory.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/ports/SkFontMgr_empty_factory.cpp b/src/ports/SkFontMgr_empty_factory.cpp
index ceed8f3320..b4232cde12 100644
--- a/src/ports/SkFontMgr_empty_factory.cpp
+++ b/src/ports/SkFontMgr_empty_factory.cpp
@@ -8,6 +8,6 @@
#include "SkFontMgr.h"
SkFontMgr* SkFontMgr::Factory() {
- // Always return NULL, an empty SkFontMgr will be used.
- return NULL;
+ // Always return nullptr, an empty SkFontMgr will be used.
+ return nullptr;
}